<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Teknisa\MAN\Services;

class ControleAcessoCaixa extends CrudWithParameterBag {
    
    protected $controleAcessoCaixaService;
    protected $dataSourceNameArray = array (
        'filterGrupoOperador' => 'vnd61000_controleAcessoCaixa',
        'filterAll' => 'vnd61000_controleAcessoCaixaAll',
        'filterGrupoSupervisores' => 'vnd61000_grpSupervisor',
        'addSupervisor' => 'vnd61000_addSupervisores'
    );
    
    protected $parameterBagColumns = array (
        'filterGrupoOperador' => array('CDGRUPOPER', 'NRORG'),
        'filterAll' => array('NRORG'),
        'addSupervisor' => array('NRORG')
    );
    
    protected static $variaveis = array (
        'IDTROCOPER' => null,
        'IDDEVITEM' => null,
        'IDCANCCUPOM' => null,
        'IDCANCULTITEM' => null,
        'IDCANCITGEN' => null,
        'IDCANCMESCOM' => null,
        'IDCONSALDO' => null,
        'IDCUPDESC' => null,
        'IDPRODCOMB' => null,
        'IDCONSPREC' => null,
        'IDRELFISCAIS' => null,
        'IDADMTEF' => null,
        'IDSANGRIA' => null,
        'IDSUPRIME' => null,
        'IDLEITUX' => null,
        'IDREDUCZ' => null,
        'IDABRGAVE' => null,
        'IDOBSPEDI' => null,
        'IDFECHACAIXA' => null,
        'IDBLOQCAIXA' => null,
        'IDLIBERAMESA' => null,
        'IDRETICONSU' => null,
        'IDRETICOUV' => null,
        'IDRETITXSERV' => null,
        'IDAGRUPAMESA' => null,
        'IDCANCAGPSEPMESA' => null,
        'IDTRANSFMESA' => null,
        'IDTRANSPROD' => null,
        'IDRELPRODVEND' => null,
        'IDPESQPROD' => null,
        'IDIMPORTDADOS' => null,
        'IDPOSIMESA' => null,
        'IDRESEMESA' => null,
        'IDALTNRPESS' => null,
        'IDPARCONTA' => null,
        'IDABERCAIXA' => null,
        'IDMULTPROD' => null,
        'IDTROCAMERCA' => null,
        'IDCUPOMACRESC' => null,
        'IDTRANSFSALDO' => null,
        'IDBLOQPROD' => null,
        'IDREIMPVNDNFCESAT' => null,
        'IDBLOQDISP' => null,
        'IDMSGPROD' => 'S',
        'IDCLINCONS' => null,
        '__is_new' => false,
        'CDGRUPOPER' => null,
        'NRORG' => null);
    
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, Services\ControleAcessoCaixa $controleAcessoCaixaService){
        $this->controleAcessoCaixa = $controleAcessoCaixaService;
        parent::__construct($dataSourceManager, $parameterBag);
    }
    
    public function findGrupoOperador(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['filterAll'];
        parent::find($request, $response);
    }   
    
    public function findgrpSupervisao(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['filterGrupoSupervisores'];
        parent::find($request, $response);
    }
    
    public function findaddSupervisao(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['addSupervisor'];
        parent::find($request, $response);
    }
    
    public function findPermissao(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        $result = $this->controleAcessoCaixa->findPermissao($row['CDGRUPOPER'], $row['NRORG']);
        if(!!$result){
            $string = $result[0]['DSSENHACAIXA'];
            $i = 0;
            
            foreach (self::$variaveis as $k => $value) {
                    if(isset($string[$i])){
                        self::$variaveis[$k] = $string[$i];
                    }
                    if(self::$variaveis[$k] == null){
                        self::$variaveis[$k] = "N";
                    }
                                    
                    $i++;
            }
            self::$variaveis['__is_new'] = false;
            self::$variaveis['CDGRUPOPER'] = $row['CDGRUPOPER'];
            self::$variaveis['NRORG'] = $row['NRORG'];
            $dataset [0] = self::$variaveis;
            $response->addDataSet(new DataSet('vnd61000_controleAcesso',$dataset));
        }
    }

    public function save(DTO\Request\DataSet $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['filterGrupoOperador'];
        try {
            $dataSet = $request->getDataSet();
            $dataSet->setDataSourceName($this->dataSourceName);
            $persistedRows = $this->dataSourceManager->persist($dataSet);
            $response->addDataSet(new DataSet($this->dataSourceName, $persistedRows));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function saveSupervisao(DTO\Request\DataSet $request, DTO\Response $response) {
        $CDGRUPOPER = $request->getDataSet()->getRows()[0]['CDGRUPOPER'];
        $NRORG = $request->getDataSet()->getRows()[0]['NRORG'];
        $result[0] = $this->controleAcessoCaixa->saveSupervisao($CDGRUPOPER, $NRORG);
        $response->addDataSet(new DataSet($this->dataSourceNameArray['addSupervisor'], $result));
    }
    
    public function deleteSupervisao(DTO\Request $request, DTO\Response $response){
        $CDGRUPOPER = $request->getRow()['CDGRUPOPER'];
        $NRORG = $request->getRow()['NRORG'];
        $result[0] = $this->controleAcessoCaixa->deleteSupervisao($CDGRUPOPER, $NRORG);
        $response->addDataSet(new DataSet($this->dataSourceNameArray['addSupervisor'], $result));
    }
    
    public function delete(DTO\Request\DataSet $request, DTO\Response $response){
        $this->dataSourceName = $this->dataSourceNameArray['filterGrupoSupervisores'];
        parent::delete($request,$response);
    }
}