<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response\Message;
use Teknisa\MAN\Utilities\Util;
use Teknisa\MAN\Services;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\Util\Functions;

class GerenciamentoComanda extends CrudWithParameterBag {
    
    protected $parameterBag;
    
    public function __construct (ParameterBag $parameterBag, Manager $dataSourceManager, $crudService, Services\GerenciamentoComandaService $gerenciamentoComandaService) {
        $this->parameterBag                     = $parameterBag;
        $this->dataSourceManager                = $dataSourceManager;
        $this->crudService                      = $crudService;
        $this->gerenciamentoComandaService      = $gerenciamentoComandaService;
    }
    
    protected $dataSourceNameArray = array( 
        'gerComanda' => 'gerenciamentoComanda',
        'findConsumidor' => 'consumidorCliComanda'
    );

    public function findComanda(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['gerComanda'];
        $this->parameterBagColumns = array('NRORG', 'CDFILIAL', 'CDLOJA');
        parent::find($request, $response);
    }
    
    public function findConsumidor(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['findConsumidor'];
        $this->parameterBagColumns = array('NRORG', 'CDFILIAL', 'CDCLIENTE');
        parent::find($request, $response);
    }
    
    public function saveComanda(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $dataSet = $request->getDataSet();
            $dataSet->setDataSourceName($this->dataSourceNameArray['gerComanda']);
            $persistedRows = $this->dataSourceManager->persist($dataSet);
            $response->addDataSet(new DataSet($this->dataSourceNameArray['gerComanda'], $persistedRows));
            
        } catch (\Exception $e) {
            $response->setCriticalError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function saveComandaAuto(DTO\Request\DataSet $request, DTO\Response $response) {
       
        $dataSet = $request->getDataSet();
        $rows = $dataSet->getRows()[0];
        $this->gerenciamentoComandaService->insereComandasAut($rows['comandas']);
         
    }
    
    
    public function saveAltComandaAuto(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $dataSet = $request->getDataSet();
            $rows = $dataSet->getRows()[0];
            $this->gerenciamentoComandaService->altComandasAut($rows['comandas']);
        } catch (\Exception $e) {
            
            if((strpos($e->getMessage(), 'ORA-00001') != false)) {
                $response->addMessage(new Message(1));
            } else {
                $response->addMessage(new Message(0));
            }
            
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function delete(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $dataSet = $request->getDataSet();
            $rows = $dataSet->getRows();
            foreach($rows as $row){
                $this->gerenciamentoComandaService->deleteComandas($row['NRORG'], $row['CDFILIAL'], $row['CDLOJA'], $row['DSCOMANDAFOS'], $row['CDOPERADOR']);
            }
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    } 
    
}